#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MASK2LOGICAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MASK2LOGICAL_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/mask2logical.hpp>

#endif
